Crate tytanic_core

The core library of the tytanic test runner.

Re-exports

pub use project::Project;
pub use suite::FilteredSuite;
pub use suite::Suite;
pub use test::Id;
pub use test::Test;

Modules

config
Reading and interpreting tytanic configuration.
doc
On-disk management of reference and test documents.
dsl
Implementations for the test set DSL. See the language reference and guide for more info.
library
Standard library augmentation, i.e. additional functions and values for the typst standard library.
project
Discovering, loading and managing typst projects.
suite
Loading and filtering of test suites, suites contain test and supplementary fields for test templates, custom test set bindings and other information necessary for managing, filtering and running tests.
test
Test loading and on-disk manipulation.

Constants

TOOL_NAME
The tool name, this is used in various places like config file directories, manifest tool sections, and more.